

set -ex



gtk-encode-symbolic-svg --help
gtk-launch --help
gtk-query-immodules-3.0
gtk-update-icon-cache --help
command -v gtk-builder-tool
command -v gtk-query-settings
test -f $PREFIX/include/gail-3.0/libgail-util/gail-util.h
test -f $PREFIX/include/gtk-3.0/gdk/gdk.h
test -f $PREFIX/include/gtk-3.0/gdk/x11/gdkx11window.h
test -f $PREFIX/include/gtk-3.0/gtk/gtk.h
test -f $PREFIX/include/gtk-3.0/unix-print/gtk/gtkunixprint.h
test -f $PREFIX/lib/pkgconfig/gail-3.0.pc
test -f $PREFIX/lib/pkgconfig/gdk-3.0.pc
test -f $PREFIX/lib/pkgconfig/gtk+-3.0.pc
test -f $PREFIX/lib/pkgconfig/gtk+-unix-print-3.0.pc
test -f $PREFIX/lib/pkgconfig/gdk-x11-3.0.pc
test -f $PREFIX/lib/pkgconfig/gtk+-x11-3.0.pc
test -f $PREFIX/lib/libgailutil-3${SHLIB_EXT}
test -f `pkg-config --variable=libdir --dont-define-prefix gail-3.0`/libgailutil-3${SHLIB_EXT}
test -f $PREFIX/lib/libgdk-3${SHLIB_EXT}
test -f `pkg-config --variable=libdir --dont-define-prefix gdk-3.0`/libgdk-3${SHLIB_EXT}
test -f $PREFIX/lib/libgtk-3${SHLIB_EXT}
test -f `pkg-config --variable=libdir --dont-define-prefix gtk+-3.0`/libgtk-3${SHLIB_EXT}
exit 0
